import React from 'react';


const InputComponent = ( props ) => {
    let inputElement = null;

    let inputClasses = ['input-element'];
     let labelClasses = ['label'];
     let containerClasses = ['input-container'];

     if(props.options){
         if(props.options.className){
             inputClasses.push(props.options.className)
         }
         if(props.options.labelClassName){
             labelClasses.push(props.options.labelClassName)
         }
         if(props.options.containerClassName){
             containerClasses.push(props.options.containerClassName)
         }
     }



    if (props.invalid && props.shouldValidate && props.touched) {

        inputClasses.push("invalid");
        if(props.options && props.options.errorClassName){
            inputClasses.push(props.options.errorClassName)
        }
    }

    switch ( props.elementType ) {
        case ( 'input' ):
            inputElement = <input
                className={inputClasses.join(' ')}
                {...props.elementConfig}
                value={props.value}
                id={props.options && props.options.id ? props.options.id : props.id}
                onChange={props.changed} />;
            break;
        case ( 'textarea' ):
            inputElement = <textarea
                className={inputClasses.join(' ')}
                {...props.elementConfig}
                value={props.value}
                  id={props.options && props.options.id ? props.options.id : props.id}
                onChange={props.changed} />;
            break;
        case ( 'select' ):
            inputElement = (
                <select
                    className={inputClasses.join(' ')}
                      id={props.options && props.options.id ? props.options.id : props.id}
                    value={props.value}
                    onChange={props.changed}>
                    {props.elementConfig.options.map(option => (
                        <option key={option.value} value={option.value}>
                            {option.displayValue}
                        </option>
                    ))}
                </select>
            );
            break;
        default:
            inputElement = <input

                {...props.elementConfig}
                value={props.value}
                onChange={props.changed} />;
    }

    return (
        <div className={containerClasses.join(' ')}>
            <label htmlFor={props.options && props.options.labelFor ? props.options.labelFor : props.id }  className={labelClasses.join(' ')}>{props.options && props.options.label ? props.options.label : "" }</label>
            {inputElement}
            {props.invalid && props.shouldValidate && props.touched ?
                [ <span className={props.options && props.options.errorClassName ? props.options.errorClassName : "error"} key={props.options && props.options.id ? props.options.id+"-error" : props.id+"-error"}>
                    {props.options && props.options.errorMsg ?props.options.errorMsg : '' }
                </span>] : []}

        </div>
    );

};

export default InputComponent;
