import React, { Component } from 'react';

import Button from './Button';
import Input from './Input';
import "./react-form.css"
class ReactForm extends Component {
    state = {
        formFields: this.props.formConfig.formFields,
    }
    componentDidMount() {
        this.props.onResetRef(this)
      }

      resetForm=()=>{
        const formFieldsToReset = {...this.state.formFields};
        for(let fieldKey in formFieldsToReset ){
          formFieldsToReset[fieldKey].value="";
          if(formFieldsToReset[fieldKey].validation.required){
          formFieldsToReset[fieldKey].valid = false;
          formFieldsToReset[fieldKey].touched = false;
          }
        }

         this.setState({formFields:formFieldsToReset})
      }
    submitHandler = ( event ) => {
        event.preventDefault();
        this.setState( { loading: true } );
        const formData = {};
        for (let formElementIdentifier in this.state.formFields) {
            formData[formElementIdentifier] = this.state.formFields[formElementIdentifier].value;
        }
        const data = formData

        this.props.onSubmitFormHandler(data);

    }

    checkFieldValidity(value, rules) {
        let isValid = true;
        if (!rules) {
            return true;
        }

        if (rules.required) {
            isValid = value.trim() !== '' && isValid;
        }

        if (rules.minLength) {
            isValid = value.length >= rules.minLength && isValid
        }

        if (rules.maxLength) {
            isValid = value.length <= rules.maxLength && isValid
        }

        if (rules.isEmail) {
            const pattern = /[a-z0-9!#$%&'*+/=?^_`{|}~-]+(?:\.[a-z0-9!#$%&'*+/=?^_`{|}~-]+)*@(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?/;
            isValid = pattern.test(value) && isValid
        }

        if (rules.isNumeric) {
            const pattern = /^\d+$/;
            isValid = pattern.test(value) && isValid
        }

        return isValid;
    }

    onChangedHandler = (event, fieldIdentifier) => {
        const updatedFields = {
            ...this.state.formFields
        };
        const updatedElement = {
            ...updatedFields[fieldIdentifier]
        };
        updatedElement.value = event.target.value;
        updatedElement.valid = this.checkFieldValidity(updatedElement.value, updatedElement.validation);
        updatedElement.touched = true;
        updatedFields[fieldIdentifier] = updatedElement;

        let formValidity = true;
        for (let fieldIdentifier in updatedFields) {
            formValidity = updatedFields[fieldIdentifier].valid && formValidity;
        }
        this.setState({formFields: updatedFields, formValidity: formValidity});
    }

    render () {
        const formElementsArray = [];
        for (let key in this.state.formFields) {
            formElementsArray.push({
                id: key,
                config: this.state.formFields[key]
            });
        }
        let form = (

            <form className={this.props.formConfig.formClassName ? this.props.formConfig.formClassName : "form"} id={this.props.formConfig.formId ? this.props.formConfig.formId : "form-id"} onSubmit={this.submitHandler}>
                {formElementsArray.map(formElement => (
                    <Input
                        id={formElement.id}
                        key={formElement.id}
                        elementType={formElement.config.elementType}
                        elementConfig={formElement.config.elementConfig}
                        value={formElement.config.value}
                        invalid={!formElement.config.valid}
                        shouldValidate={formElement.config.validation}
                        touched={formElement.config.touched}
                        options={formElement.config.options ? formElement.config.options : null }
                        changed={(event) => this.onChangedHandler(event, formElement.id)} />
                ))}
                <div className={this.props.formConfig.submitBtnOptions && this.props.formConfig.submitBtnOptions.containerClassName ? this.props.formConfig.submitBtnOptions.containerClassName : "" }>
                    <Button btnClass={this.props.formConfig.submitBtnOptions && this.props.formConfig.submitBtnOptions.className? this.props.formConfig.submitBtnOptions.className : ""} id={this.props.formConfig.submitBtnOptions && this.props.formConfig.submitBtnOptions.btnId? this.props.formConfig.submitBtnOptions.btnId : "submit-btn"}  disabled={!this.state.formValidity}>{
                      this.props.formConfig.submitBtnOptions && this.props.formConfig.submitBtnOptions.btnText? this.props.formConfig.submitBtnOptions.btnText : "Submit"
                    }</Button>
                </div>
            </form>
        );
        return (
            <div className={this.props.formConfig.containerClassName ? this.props.formConfig.containerClassName : ""}>
                {form}
            </div>
        );
    }
}

export default ReactForm;
